# Convert KMs to Miles

This is a basic library that converts given Kilometers into Miles. 

## Installation 
You can install this library using Python Package Manager. 
```
python -m pip install realpython-reader
```

The reader is supported on Python 3.7 and above. Older versions of Python, including Python 2.7, are supported by version 1.0.0 of the reader.

